@@ -1,24 +1,22 @@
-/*****************************************************************************\
- *  $Id:$
- *****************************************************************************
- *  Copyright (C) 2004-2008 The Regents of the University of California.
+/*****************************************************************************
+ *  Copyright (C) 2004 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Jim Garlick <garlick@llnl.gov>
  *  UCRL-CODE-2002-008.
- *  
+ *
  *  This file is part of PowerMan, a remote power management program.
  *  For details, see <http://www.llnl.gov/linux/powerman/>.
- *  
+ *
  *  PowerMan is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
- *  
- *  PowerMan is distributed in the hope that it will be useful, but WITHOUT 
- *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
- *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License 
+ *
+ *  PowerMan is distributed in the hope that it will be useful, but WITHOUT
+ *  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ *  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  *  for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License along
  *  with PowerMan; if not, write to the Free Software Foundation, Inc.,
  *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
@@ -68,10 +66,10 @@ static const struct option longopts[] = {
 #endif
 
 
-int 
+int
 main(int argc, char *argv[])
 {
-    int i, c;
+    int c;
     baytype_t personality = NONE;
 
     prog = basename(argv[0]);
@@ -120,14 +118,14 @@ main(int argc, char *argv[])
     exit(0);
 }
 
-static void 
+static void
 usage(void)
 {
     fprintf(stderr, "Usage: %s -p rpc3|rpc3-nc|rpc28-nc|rpc3-de\n", prog);
     exit(1);
 }
 
-static void 
+static void
 _noop_handler(int signum)
 {
     fprintf(stderr, "%s: received signal %d\n", prog, signum);
@@ -217,7 +215,7 @@ Maximum Detected:     6.9 Amps      :      2.8 Amps\r\n\
 Type \"Help\" for a list of commands\r\n\
 \r\n"
 
-static void 
+static void
 _prompt_loop_rpc28_nc(void)
 {
     int i;
@@ -240,22 +238,22 @@ _prompt_loop_rpc28_nc(void)
             break;
         if (strlen(buf) == 0) {
             continue;
-        } else if (!strcmp(buf, "logoff") || !strcmp(buf, "logout") 
+        } else if (!strcmp(buf, "logoff") || !strcmp(buf, "logout")
                                           || !strcmp(buf, "exit")) {
             break;
         } else if (!strcmp(buf, "help")) {
-            printf(RPC28_NC_HELP); 
+            printf(RPC28_NC_HELP);
         } else if (!strcmp(buf, "temp"))
-            printf(RPC28_NC_TEMP); 
+            printf(RPC28_NC_TEMP);
         else if (!strcmp(buf, "voltage"))
-            printf(RPC28_NC_VOLTAGE); 
+            printf(RPC28_NC_VOLTAGE);
         else if (!strcmp(buf, "current"))
-            printf(RPC28_NC_CURRENT); 
+            printf(RPC28_NC_CURRENT);
         else if (!strcmp(buf, "status")) {
-            printf(RPC28_NC_STATUS, 
-                   plug[0], plug[1], plug[2], plug[3],  
+            printf(RPC28_NC_STATUS,
+                   plug[0], plug[1], plug[2], plug[3],
                    plug[4], plug[5], plug[6], plug[7],
-                   plug[8], plug[9], plug[10], plug[11],  
+                   plug[8], plug[9], plug[10], plug[11],
                    plug[12], plug[13], plug[14], plug[15],
                    plug[16], plug[17], plug[18], plug[19]);
 /* NOTE: we only suport one plug at a time or all for on,off,reboot */
@@ -284,7 +282,7 @@ _prompt_loop_rpc28_nc(void)
                     fflush(stdout);
                     sleep(1);
                 }
-                printf("\r\n");   
+                printf("\r\n");
             } else
                 goto err;
         } else
@@ -407,7 +405,7 @@ Type Help for a list of commands\r\n\
 \r\n"
 
 
-static void 
+static void
 _prompt_loop_rpc3_de(void)
 {
     int i;
@@ -427,22 +425,22 @@ _prompt_loop_rpc3_de(void)
             break;
         if (strlen(buf) == 0) {
             continue;
-        } else if (!strcmp(buf, "logoff") || !strcmp(buf, "logout") 
+        } else if (!strcmp(buf, "logoff") || !strcmp(buf, "logout")
                                           || !strcmp(buf, "exit")) {
             break;
         } else if (!strcmp(buf, "help")) {
-            printf(RPC3_DE_HELP); 
+            printf(RPC3_DE_HELP);
         } else if (!strcmp(buf, "temp"))
-            printf(RPC3_DE_TEMP); 
+            printf(RPC3_DE_TEMP);
         else if (!strcmp(buf, "voltage"))
-            printf(RPC3_DE_VOLTAGE); 
+            printf(RPC3_DE_VOLTAGE);
         else if (!strcmp(buf, "current"))
-            printf(RPC3_DE_CURRENT); 
+            printf(RPC3_DE_CURRENT);
         else if (!strcmp(buf, "power"))
-            printf(RPC3_DE_POWER); 
+            printf(RPC3_DE_POWER);
         else if (!strcmp(buf, "status")) {
-            printf(RPC3_DE_STATUS, 
-                   plug[0], plug[1], plug[2], plug[3],  
+            printf(RPC3_DE_STATUS,
+                   plug[0], plug[1], plug[2], plug[3],
                    plug[4], plug[5], plug[6], plug[7]);
 /* NOTE: we only suport one plug at a time or all for on,off,reboot */
         } else if (sscanf(buf, "on %d", &i) == 1) {
@@ -470,7 +468,7 @@ _prompt_loop_rpc3_de(void)
                     fflush(stdout);
                     sleep(1);
                 }
-                printf("\r\n");   
+                printf("\r\n");
             } else
                 goto err;
         } else
@@ -561,7 +559,7 @@ Maximum Detected:     4.3 Amps\r\n\
 Type \"Help\" for a list of commands\r\n\
 \r\n"
 
-static void 
+static void
 _prompt_loop_rpc3_nc(void)
 {
     int i;
@@ -581,20 +579,20 @@ _prompt_loop_rpc3_nc(void)
             break;
         if (strlen(buf) == 0) {
             continue;
-        } else if (!strcmp(buf, "logoff") || !strcmp(buf, "logout") 
+        } else if (!strcmp(buf, "logoff") || !strcmp(buf, "logout")
                                           || !strcmp(buf, "exit")) {
             break;
         } else if (!strcmp(buf, "help")) {
-            printf(RPC3_NC_HELP); 
+            printf(RPC3_NC_HELP);
         } else if (!strcmp(buf, "temp"))
-            printf(RPC3_NC_TEMP); 
+            printf(RPC3_NC_TEMP);
         else if (!strcmp(buf, "voltage"))
-            printf(RPC3_NC_VOLTAGE); 
+            printf(RPC3_NC_VOLTAGE);
         else if (!strcmp(buf, "current"))
-            printf(RPC3_NC_CURRENT); 
+            printf(RPC3_NC_CURRENT);
         else if (!strcmp(buf, "status")) {
-            printf(RPC3_NC_STATUS, 
-                   plug[0], plug[1], plug[2], plug[3],  
+            printf(RPC3_NC_STATUS,
+                   plug[0], plug[1], plug[2], plug[3],
                    plug[4], plug[5], plug[6], plug[7]);
 /* NOTE: we only suport one plug at a time or all for on,off,reboot */
         } else if (sscanf(buf, "on %d", &i) == 1) {
@@ -622,7 +620,7 @@ _prompt_loop_rpc3_nc(void)
                     fflush(stdout);
                     sleep(1);
                 }
-                printf("\r\n");   
+                printf("\r\n");
             } else
                 goto err;
         } else
@@ -706,7 +704,7 @@ err:
 \r\n\
   <Strike CR to continue.>"
 
-static void 
+static void
 _prompt_loop_rpc3(void)
 {
     int i;
@@ -715,7 +713,7 @@ _prompt_loop_rpc3(void)
     char plug[8][4];
     int plug_origin = 1;
     enum { START, MENU, OUTLET, QUIT } state = START;
-    char *prompt;
+    char *prompt = NULL;
 
     for (i = 0; i < num_plugs; i++)
         strcpy(plug[i], "Off");
@@ -735,6 +733,8 @@ _prompt_loop_rpc3(void)
                                     plug[4], plug[5], plug[6], plug[7]);
                 prompt = RPC3_PROMPT;
                 break;
+            case QUIT:
+                break;
         }
         if (xreadline(prompt, buf, sizeof(buf)) == NULL) {
             state = QUIT;
@@ -784,13 +784,15 @@ _prompt_loop_rpc3(void)
                 } else
                     goto err;
                 break;
+            case QUIT:
+                break;
         }
         continue;
 err:
         printf("\r\n  Input error.\r\n\r\n");
     }
 }
-        
+
 /*
  * vi:tabstop=4 shiftwidth=4 expandtab
  */
